@@ -1,6 +1,6 @@
 import importlib
 import pkgutil
-__all__ = []
+__all__ = [] # expose objax implementation as base nn
 module = importlib.import_module('.'+'objax',package=__name__)
 globals().update({k: getattr(module, k) for k in module.__all__})
 __all__ += module.__all__
